@@ -16,6 +16,7 @@ import pendulum
 from arg_services.graph.v1 import graph_pb2
 from google.protobuf.json_format import MessageToDict, ParseDict
 from lxml import html
+from pendulum.datetime import DateTime
 
 from arguebuf.data import Metadata, Participant, Reference, Resource
 
@@ -74,8 +75,8 @@ class Graph:
     _major_claim: t.Optional[AtomNode]
     analysts: t.List[Participant]
     version: str
-    created: pendulum.DateTime
-    updated: pendulum.DateTime
+    created: DateTime
+    updated: DateTime
     metadata: Metadata
 
     @property
@@ -535,6 +536,7 @@ class Graph:
         end_node: Node,
         max_distance: t.Optional[int] = None,
         directed: bool = True,
+        ignore_schemes: bool = False,
     ) -> t.Optional[int]:
         """Get the distance between `start_node` and `end_node` in the graph.
 
@@ -573,14 +575,14 @@ class Graph:
             if start_node == end_node:
                 return 0
 
-            dist = _node_distance(
-                start_node, end_node, self._outgoing_nodes, max_distance
+            connections = (
+                self.outgoing_atom_nodes if ignore_schemes else self.outgoing_nodes
             )
 
+            dist = _node_distance(start_node, end_node, connections, max_distance)
+
             if dist is None and not directed:
-                dist = _node_distance(
-                    end_node, start_node, self._outgoing_nodes, max_distance
-                )
+                dist = _node_distance(end_node, start_node, connections, max_distance)
 
             return dist
 
@@ -628,9 +630,7 @@ class Graph:
                 g._major_claim = node
 
         for ova_edge in obj["edges"]:
-            edge = edge_class.from_ova(ova_edge, g._nodes)
-
-            if edge:
+            if edge := edge_class.from_ova(ova_edge, g._nodes):
                 g.add_edge(edge)
 
         if analysis and analysis.get("txt"):
@@ -645,9 +645,7 @@ class Graph:
                 if elem.tag == "span":
                     # The id is prefixed with 'node', e.g. 'node5'.
                     node_key = elem.attrib["id"].replace("node", "")
-                    node = g._atom_nodes.get(node_key)
-
-                    if node:
+                    if node := g._atom_nodes.get(node_key):
                         node.reference = Reference(
                             resource, len(text), utils.parse(elem.text, nlp)
                         )
@@ -655,11 +653,9 @@ class Graph:
                     if elem.text:
                         text += elem.text
 
-                # A line break does not contain text, thus we only insert a newline
                 elif elem.tag == "br":
                     text += "\n"
 
-                # All other elements (e.g., the body tag) are just added to the text
                 elif elem.text:
                     text += elem.text
 
@@ -1224,10 +1220,10 @@ class Graph:
 def _node_distance(
     node1: Node,
     node2: Node,
-    connections: t.Mapping[Node, t.Iterable[Node]],
+    connections: t.Callable[[Node], t.Iterable[Node]],
     max_distance: t.Optional[int],
 ) -> t.Optional[int]:
-    expansion: t.List[t.Tuple[Node, int]] = [(n, 1) for n in connections[node1]]
+    expansion: t.List[t.Tuple[Node, int]] = [(n, 1) for n in connections(node1)]
 
     while len(expansion) > 0:
         candidate, distance = expansion.pop()
@@ -1237,7 +1233,7 @@ def _node_distance(
         elif candidate == node2:
             return distance
         else:
-            expansion.extend((n, distance + 1) for n in connections[candidate])
+            expansion.extend((n, distance + 1) for n in connections(candidate))
 
     return None
 
